synapse.util.stringutils module — Synapse 1.0 documentation

# synapse.util.stringutils module

`synapse.util.stringutils.` `exception_to_unicode`(e)

  Helper function to extract the text of an exception as a unicode string

  Parameters: | e (Exception) – exception to be stringified
  Returns: | unicode

`synapse.util.stringutils.` `is_ascii`(s)

`synapse.util.stringutils.` `random_string`(length)

`synapse.util.stringutils.` `random_string_with_symbols`(length)

`synapse.util.stringutils.` `to_ascii`(s)

  Converts a string to ascii if it is ascii, otherwise leave it alone.

  If given None then will return None.